;; Generated package description from simple-httpd.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "simple-httpd" "1.5.1" "pure elisp HTTP server" '((cl-lib "0.3")) :commit "a5eb49a6567e33586fba15dd649d63ca6e964314" :authors '(("Christopher Wellons" . "wellons@nullprogram.com")) :maintainer '("Christopher Wellons" . "wellons@nullprogram.com") :url "https://github.com/skeeto/emacs-http-server")
